import { OnInit, OnChanges, OnDestroy, EventEmitter, ChangeDetectorRef } from '@angular/core';
import { CalendarEvent } from '../../utils/CalendarEvent';
import { Calendar } from '../../utils/Calendar';
import { WeekDay } from '../../utils/week-day';
import { MonthViewDay } from '../../utils/month/MonthViewDay';
import { CalendarEventTimesChangedEvent } from '../../utils/CalendarEventTimesChangedEvent';
import { CalendarUtilsService } from './../../utils/calendar-utils.service';
import { MonthViewEvent } from '../../utils/month/MonthViewEvent';
import { Subject } from 'rxjs/Subject';
import { Subscription } from 'rxjs/Subscription';
export declare class MonthViewComponent implements OnInit, OnChanges, OnDestroy {
    private cdr;
    private utils;
    /**
    * The current view date
    */
    viewDate: Date;
    /**
    * An array of events to display on view.
    */
    events: CalendarEvent[];
    /**
    * An array of calendars to display on view.
    */
    calendars: Calendar[];
    /**
    * An array of day indexes (0 = sunday, 1 = monday etc) that will be hidden on the view
    */
    excludeDays: number[];
    /**
    * Whether the events list for the day of the `viewDate` option is visible or not
    */
    activeDayIsOpen: boolean;
    /**
    * An observable that when emitted on will re-render the current view
    */
    refresh: Subject<any>;
    /**
    * The locale used to format dates
    */
    locale: string;
    /**
    * The start number of the week
    */
    weekStartsOn: number;
    /**
    * An array of day indexes (0 = sunday, 1 = monday etc) that indicate which days are weekends
    */
    weekendDays: number[];
    /**
    * An output that will be called before the view is rendered for the current month.
    * If you add the `cssClass` property to a day in the body it will add that class to the cell element in the template
    */
    beforeViewRender: EventEmitter<{
        header: WeekDay[];
        body: MonthViewDay[];
    }>;
    /**
    * Called when the day cell is clicked
    */
    dayClicked: EventEmitter<{
        day: MonthViewDay;
    }>;
    /**
    * Called when the event title is clicked
    */
    eventClicked: EventEmitter<{
        event: CalendarEvent;
    }>;
    /**
    * Called when an event is dragged and dropped
    */
    eventTimesChanged: EventEmitter<CalendarEventTimesChangedEvent>;
    /**
     * @hidden
     */
    columnHeaders: any;
    /**
     * @hidden
     */
    view: any;
    /**
     * @hidden
     */
    monthEvents: MonthViewEvent[];
    /**
     * @hidden
     */
    openRowIndex: any;
    /**
     * @hidden
     */
    openDay: any;
    /**
     * @hidden
     */
    refreshSubscription: Subscription;
    /**
     * @hidden
     */
    constructor(cdr: ChangeDetectorRef, utils: CalendarUtilsService, locale: string);
    ngOnInit(): void;
    /**
     * @hidden
     */
    ngOnChanges(changes: any): void;
    /**
     * @hidden
     */
    ngOnDestroy(): void;
    private refreshHeader();
    private refreshEvents();
    private refreshBody();
    private emitBeforeViewRender();
    private checkActiveDayIsOpen();
    private refreshAll();
}
