import { OnInit, OnChanges, EventEmitter, ChangeDetectorRef } from '@angular/core';
import { CalendarEvent } from '../../utils/CalendarEvent';
import { Calendar } from '../../utils/Calendar';
import { WeekDay } from '../../utils/week-day';
import { DayViewHour } from '../../utils/day/DayViewHour';
import { Subject } from 'rxjs/Subject';
import { Subscription } from 'rxjs/Subscription';
import { CalendarUtilsService } from '../../utils/calendar-utils.service';
export declare class WeekViewComponent implements OnInit, OnChanges {
    private cdr;
    private utils;
    /**
     * The current view date
     */
    viewDate: Date;
    /**
     * An array of events to display on view
     */
    events: CalendarEvent[];
    /**
    * An array of calendars to display on view.
    */
    calendars: Calendar[];
    /**
     * The start number of the week
     */
    weekStartsOn: number;
    /**
     * An array of day indexes (0 = sunday, 1 = monday etc) that will be hidden on the view
     */
    excludeDays: number[];
    /**
    * An array of day indexes (0 = sunday, 1 = monday etc) that indicate which days are weekends
    */
    weekendDays: number[];
    /**
   * @hidden
   */
    days: WeekDay[];
    /**
    * @hidden
    */
    hours: DayViewHour[];
    /**
    * An observable that when emitted on will re-render the current view
    */
    refresh: Subject<any>;
    /**
    * The precision to display events.
    * `days` will round event start and end dates to the nearest day and `minutes` will not do this rounding
    */
    precision: 'days' | 'minutes';
    /**
    * The number of segments in an hour. Must be <= 6
    */
    hourSegments: number;
    /**
    * The height in pixels of each hour segment
    */
    hourSegmentHeight: number;
    /**
    * The day start hours in 24 hour time. Must be 0-23
    */
    dayStartHour: number;
    /**
    * The day start minutes. Must be 0-59
    */
    dayStartMinute: number;
    /**
    * The day end hours in 24 hour time. Must be 0-23
    */
    dayEndHour: number;
    /**
    * The day end minutes. Must be 0-59
    */
    dayEndMinute: number;
    /**
     * The width in pixels of each event on the view
     */
    eventWidth: number;
    /**
     * An output that will be called before the view is rendered for the current week.
     * If you add the `cssClass` property to a day in the header it will add that class to the cell element in the template
     */
    beforeViewRender: EventEmitter<{
        header: WeekDay[];
        body: DayViewHour[];
    }>;
    /**
     * Called when the event title is clicked
     */
    eventClicked: EventEmitter<{
        event: CalendarEvent;
    }>;
    /**
     * @hidden
     */
    view: any;
    /**
    * @hidden
    */
    refreshSubscription: Subscription;
    currentTime: number;
    constructor(cdr: ChangeDetectorRef, utils: CalendarUtilsService);
    ngOnInit(): void;
    /**
   * @hidden
   */
    ngOnChanges(changes: any): void;
    getCurrentTime(): number;
    private refreshBody();
    private refreshHeader();
    refreshAll(): void;
}
